# dotignore

[![Version](https://img.shields.io/pypi/v/dotignore)](https://pypi.org/project/dotignore)
[![License](https://img.shields.io/pypi/l/dotignore)](https://pypi.org/project/dotignore)

Command line tool to generate dotignore files

![Demo](https://gist.githubusercontent.com/Xvezda/2088adeb8efc42e724c1871942c87583/raw/dotignore.gif)

## Installation
```sh
pip install dotignore
```

## License

Copyright (C) 2020 [Xvezda](mailto:xvezda@naver.com)

[MIT License](LICENSE)


## TODO

- [ ] Support other dotignore files (e.g. `.npmignore`, `.dockerignore`, etc.)
- [ ] Write test
